( cd usr/lib ; rm -rf libgpgme-pthread.so.11 )
( cd usr/lib ; ln -sf libgpgme-pthread.so.11.6.4 libgpgme-pthread.so.11 )
( cd usr/lib ; rm -rf libgpgme.so.11 )
( cd usr/lib ; ln -sf libgpgme.so.11.6.4 libgpgme.so.11 )
( cd usr/lib ; rm -rf libgpgme-pth.so.11 )
( cd usr/lib ; ln -sf libgpgme-pth.so.11.6.4 libgpgme-pth.so.11 )
( cd usr/lib ; rm -rf libgpgme-pth.so )
( cd usr/lib ; ln -sf libgpgme-pth.so.11.6.4 libgpgme-pth.so )
( cd usr/lib ; rm -rf libgpgme.so )
( cd usr/lib ; ln -sf libgpgme.so.11.6.4 libgpgme.so )
( cd usr/lib ; rm -rf libgpgme-pthread.so )
( cd usr/lib ; ln -sf libgpgme-pthread.so.11.6.4 libgpgme-pthread.so )
